unit Childwin;

interface

uses
  Windows, Classes, Graphics, Forms, Controls, StdCtrls, ComCtrls, SysUtils,
  Menus;

type
  TMDIChild = class(TForm)
    lvJobEnum: TListView;
    PopupMenu: TPopupMenu;
    Add1: TMenuItem;
    Change1: TMenuItem;
    Remove1: TMenuItem;
    Refresh1: TMenuItem;
    Copy1: TMenuItem;
    Paste1: TMenuItem;
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormCreate(Sender: TObject);
    procedure lvJobEnumSelectItem(Sender: TObject; Item: TListItem;
      Selected: Boolean);
    procedure lvJobEnumDblClick(Sender: TObject);
  private
    { Private declarations }
    FJobId      : LongWord;
    FServername : String;
    procedure ClearLvJobEnum;
    procedure RequeryLvJobEnum;
    procedure SetServername(const Value: String);
  public
    { Public declarations }
    function  JobExists(JobId: LongWord): Boolean;
    procedure RefreshLvJobEnum;
  published
    property JobId : LongWord read FJobId write FJobId;
    property Servername : String read FServername write SetServername;
  end;

var
  MDIChild : TMDIChild;

implementation

uses
  LMat, Main, NetScheduleJob, AddChange;

{$R *.DFM}

//------------------------------------------------------------------------------
function TMDIChild.JobExists(JobId: LongWord): Boolean;
var
  i : Integer;
begin
  Result := False;
  for i := 0 to lvJobEnum.Items.Count-1 do
    if JobId = StrToInt(lvJobEnum.Items[i].Caption) then
    begin
      Result := True;
      break;
    end;
end;

//------------------------------------------------------------------------------
procedure TMDIChild.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  Action := caFree;
end;

//------------------------------------------------------------------------------
procedure TMDIChild.SetServername(const Value: String);
begin
  if (Value <> FServername) then
  begin
    FServername := Value;
    Caption := '\\' + FServername;
  end;
end;

//------------------------------------------------------------------------------
procedure TMDIChild.RefreshLvJobEnum;
begin
  ClearLvJobEnum;
  RequeryLvJobEnum;
end;

//------------------------------------------------------------------------------
procedure TMDIChild.ClearLvJobEnum;
begin
  while (lvJobEnum.Items.Count > 0) do
    lvJobEnum.Items.Delete(0);
end;

//------------------------------------------------------------------------------
procedure TMDIChild.RequeryLvJobEnum;
var
  pAtEnum      : PAT_ENUM;
  EntriesRead  : LongWord;
  TotalEntries : LongWord;
  ResumeHandle : LongWord;
  EnumBuffer   : Pointer;
  i            : Integer;
  ListItem     : TListItem;
  Dest         : TServername;
begin
  StringToWideChar(Servername, @Dest, SizeOf(Dest) div 2);

  ResumeHandle := 0;

  NetScheduleJobEnum(Dest,
                     PBYTE(@EnumBuffer),
                     LongWord(-1),
                     @EntriesRead,
                     @TotalEntries,
                     @ResumeHandle);

  if (TotalEntries = 0) then exit;

  pATEnum := EnumBuffer;
  for i := 1 to TotalEntries do
  begin
    ListItem := lvJobEnum.Items.Add;
    ListItem.Caption := JobIdToStr(pAtEnum^.JobId);

    if RunPeriodically(pAtEnum^.Flags) then
      ListItem.SubItems.Add('yes')
    else
      ListItem.SubItems.Add('no');

    ListItem.SubItems.Add(DaysOfWeekToStr(pAtEnum^.DaysOfWeek));
    ListItem.SubItems.Add(DaysOfMonthToStr(pAtEnum^.DaysOfMonth));
    ListItem.SubItems.Add(JobTimeToStr(pAtEnum^.JobTime));
    ListItem.SubItems.Add(pAtEnum^.Command);

    if RunToday(pAtEnum^.Flags) then
      ListItem.SubItems.Add('yes')
    else
      ListItem.SubItems.Add('no');

    if RunInteractive(pAtEnum^.Flags) then
      ListItem.SubItems.Add('yes')
    else
      ListItem.SubItems.Add('no');

    if ExecError(pAtEnum^.Flags) then
      ListItem.SubItems.Add('yes')
    else
      ListItem.SubItems.Add('no');
      
    Inc(pAtEnum);
  end;
end;

//------------------------------------------------------------------------------
procedure TMDIChild.FormCreate(Sender: TObject);
begin
  RefreshLvJobEnum;
end;

//------------------------------------------------------------------------------
procedure TMDIChild.lvJobEnumSelectItem(Sender: TObject; Item: TListItem;
  Selected: Boolean);
begin
  JobId := StrToIntDef(Item.Caption, 0);
  MainForm.JobId := JobId;
end;

//------------------------------------------------------------------------------
procedure TMDIChild.lvJobEnumDblClick(Sender: TObject);
begin
  if not JobExists(FJobId) then
    exit;

  AddChangeForm := TAddChangeForm.Create(Application);
  with AddChangeForm do
  begin
    try
      Caption := 'Change job ' + IntToStr(FJobId) + ' on \\' + FServername;
      JobId := FJobId;
      Servername := FServername;
      JobShow;
      if (AddChangeForm.ShowModal = mrOk) then
        RefreshLvJobEnum;
    finally
      AddChangeForm.Free;
    end;
  end;
end;

end.
